package com.ruoyi.system.service.impl;

import java.util.Date;
import java.util.List;
import com.ruoyi.common.utils.DateUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.ruoyi.system.mapper.PostNoticeMapper;
import com.ruoyi.system.domain.PostNotice;
import com.ruoyi.system.service.IPostNoticeService;

import javax.xml.crypto.Data;

/**
 * 公告Service业务层处理
 *
 * @author ruoyi
 * @date 2023-01-14
 */
@Service
public class PostNoticeServiceImpl implements IPostNoticeService
{
    @Autowired
    private PostNoticeMapper postNoticeMapper;

    /**
     * 查询公告
     *
     * @param noticeId 公告主键
     * @return 公告
     */
    @Override
    public PostNotice selectPostNoticeByNoticeId(Long noticeId)
    {
        return postNoticeMapper.selectPostNoticeByNoticeId(noticeId);
    }

    /**
     * 查询公告列表
     *
     * @param postNotice 公告
     * @return 公告
     */
    @Override
    public List<PostNotice> selectPostNoticeList(PostNotice postNotice)
    {
        return postNoticeMapper.selectPostNoticeList(postNotice);
    }


    @Override
    public String selectDetailByNoticeId(Long noticeId) {
        return postNoticeMapper.selectDetailByNoticeId(noticeId);
    }


    /**
     * 搜素
     * @param noticeTitle
     * @param noticeTimeLeft
     * @param noticeTimeRight
     * @return
     */
    @Override
    public List<PostNotice> selectPostNoticeListByTitleOrNoticeTime(String noticeTitle, Date noticeTimeLeft, Date noticeTimeRight) {
        return postNoticeMapper.selectPostNoticeListByTitleOrNoticeTime(noticeTitle,noticeTimeLeft,noticeTimeRight);
    }

    /**
     * 新增公告
     *
     * @param postNotice 公告
     * @return 结果
     */
    @Override
    public int insertPostNotice(PostNotice postNotice)
    {
        postNotice.setCreateTime(DateUtils.getNowDate());
        return postNoticeMapper.insertPostNotice(postNotice);
    }

    /**
     * 修改公告
     *
     * @param postNotice 公告
     * @return 结果
     */
    @Override
    public int updatePostNotice(PostNotice postNotice)
    {
        postNotice.setUpdateTime(DateUtils.getNowDate());
        return postNoticeMapper.updatePostNotice(postNotice);
    }

    /**
     * 批量删除公告
     *
     * @param noticeIds 需要删除的公告主键
     * @return 结果
     */

    @Override
    public int deletePostNoticeByNoticeIds(Long[] noticeIds)
    {
        return postNoticeMapper.deletePostNoticeByNoticeIds(noticeIds);
    }

    /**
     * 删除公告信息
     *
     * @param noticeId 公告主键
     * @return 结果
     */
    @Override
    public int deletePostNoticeByNoticeId(Long noticeId)
    {
        return postNoticeMapper.deletePostNoticeByNoticeId(noticeId);
    }

}
